@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import print_function
@@ -22,12 +22,12 @@ from __future__ import print_function
 from datetime import datetime, timedelta
 import re
 import sys
-from urlparse import urlsplit
 from random import choice
+from collections import OrderedDict
 
 from weboob.capabilities.content import CapContent
 from weboob.tools.application.repl import ReplApplication
-from weboob.tools.ordereddict import OrderedDict
+from weboob.tools.compat import urlsplit
 
 
 __all__ = ['Boobathon']
@@ -233,7 +233,7 @@ h2. Attendees
        self.format_duration() or '_Unknown_',
        self.location or '_Unknown_')
 
-        for member in self.members.itervalues():
+        for member in self.members.values():
             if self.date:
                 availabilities = ''
             else:
@@ -278,8 +278,8 @@ h2. Attendees
 
 class Boobathon(ReplApplication):
     APPNAME = 'boobathon'
-    VERSION = '1.0'
-    COPYRIGHT = 'Copyright(C) 2011 Romain Bignon'
+    VERSION = '1.5'
+    COPYRIGHT = 'Copyright(C) 2011-YEAR Romain Bignon'
     DESCRIPTION = 'Console application to participate to a Boobathon.'
     SHORT_DESCRIPTION = "participate in a Boobathon"
     CAPS = CapContent
@@ -289,14 +289,14 @@ class Boobathon(ReplApplication):
     radios = []
 
     def __init__(self, *args, **kwargs):
-        ReplApplication.__init__(self, *args, **kwargs)
+        super(Boobathon, self).__init__(*args, **kwargs)
 
     def main(self, argv):
         if len(argv) < 2:
             print('Please give the name of the boobathon', file=self.stderr)
             return 1
 
-        self.event = Event(argv[1], choice(self.weboob.backend_instances.values()))
+        self.event = Event(argv[1], choice(list(self.weboob.backend_instances.values())))
         if self.event.description is None:
             if not self.ask("This event doesn't seem to exist. Do you want to create it?", default=True):
                 return 1
@@ -355,7 +355,7 @@ class Boobathon(ReplApplication):
         Display progress of members.
         """
         self.event.load()
-        for member in self.event.members.itervalues():
+        for member in self.event.members.values():
             if member.is_me and member is self.event.winner:
                 status = '\o/ ->'
             elif member.is_me:
@@ -388,7 +388,7 @@ class Boobathon(ReplApplication):
             cur = (datetime.now() - self.event.begin).seconds
             pct = cur*20/tot
             progress = ''
-            for i in xrange(20):
+            for i in range(20):
                 if i < pct:
                     progress += '='
                 elif i == pct:
@@ -421,7 +421,7 @@ class Boobathon(ReplApplication):
             if i >= 0 and i%2:
                 # second line of task, see if we'll stop
                 stop = True
-            for mem in self.event.members.itervalues():
+            for mem in self.event.members.values():
                 if len(mem.tasks) > (i/2+1):
                     # there are more tasks, don't stop now
                     stop = False
@@ -455,7 +455,7 @@ class Boobathon(ReplApplication):
         args = line.split(' ')
         if len(args) == 2:
             self.event.load()
-            return [member.name for member in self.event.members.itervalues()]
+            return [member.name for member in self.event.members.values()]
 
     def do_close(self, name):
         """
@@ -465,7 +465,7 @@ class Boobathon(ReplApplication):
         """
         self.event.load()
 
-        for member in self.event.members.itervalues():
+        for member in self.event.members.values():
             if member.name == name:
                 self.event.winner = member
                 if self.save_event('Close event'):
@@ -533,7 +533,7 @@ class Boobathon(ReplApplication):
         Display members information.
         """
         self.event.load()
-        for member in self.event.members.itervalues():
+        for member in self.event.members.values():
             print(member.name)
             print('-' * len(member.name))
             print('Repository:', member.repository)
@@ -772,16 +772,16 @@ class Boobathon(ReplApplication):
         """
         Overload a Application method.
         """
-        for instance_name, backend_name, params in self.weboob.backends_config.iter_backends():
-            if backend_name != 'redmine':
+        for backend_name, module_name, params in self.weboob.backends_config.iter_backends():
+            if module_name != 'redmine':
                 continue
             v = urlsplit(params['url'])
             if v.netloc == 'symlink.me':
-                self.load_backends(names=[instance_name])
+                self.load_backends(names=[backend_name])
                 return
 
         if not self.check_loaded_backends({'url': 'https://symlink.me'}):
-            print("Ok, so leave now, fag.")
+            print("Ok, so leave now.")
             sys.exit(0)
 
     def is_module_loadable(self, module):
