@@ -5,29 +5,29 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
 from weboob.capabilities.recipe import CapRecipe
-from weboob.tools.application.qt import QtApplication
+from weboob.tools.application.qt5 import QtApplication
 
 from .main_window import MainWindow
 
 
 class QCookboob(QtApplication):
     APPNAME = 'qcookboob'
-    VERSION = '1.0'
-    COPYRIGHT = 'Copyright(C) 2013 Julien Veyssier'
+    VERSION = '1.5'
+    COPYRIGHT = 'Copyright(C) 2013-2014 Julien Veyssier'
     DESCRIPTION = "Qt application allowing to search recipes."
     SHORT_DESCRIPTION = "search recipes"
     CAPS = CapRecipe
@@ -40,6 +40,6 @@ class QCookboob(QtApplication):
         self.load_backends([CapRecipe])
         self.load_config()
 
-        self.main_window = MainWindow(self.config, self.weboob, self)
-        self.main_window.show()
+        main_window = MainWindow(self.config, self.weboob, self)
+        main_window.show()
         return self.weboob.loop()
