@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import print_function
@@ -28,6 +28,7 @@ from PyQt5.QtWidgets import QFrame, QFileDialog
 
 from weboob.applications.qcookboob.ui.recipe_ui import Ui_Recipe
 from weboob.capabilities.base import empty
+from weboob.tools.capabilities.recipe import recipe_to_krecipes_xml
 
 
 class Recipe(QFrame):
@@ -86,8 +87,13 @@ class Recipe(QFrame):
         self.ui.verticalLayout_2.setAlignment(Qt.AlignTop)
 
     def gotThumbnail(self):
-        if self.recipe.picture_url and not empty(self.recipe.picture_url):
-            data = requests.get(self.recipe.picture_url).content
+        try:
+            url = self.recipe.picture.url
+        except AttributeError:
+            return
+
+        if not empty(url):
+            data = requests.get(url).content
             img = QImage.fromData(data)
             self.ui.imageLabel.setPixmap(QPixmap.fromImage(img).scaledToWidth(250, Qt.SmoothTransformation))
 
@@ -106,7 +112,7 @@ class Recipe(QFrame):
             dest = result[0]
             if not dest.endswith('.kreml'):
                 dest += '.kreml'
-            data = self.recipe.toKrecipesXml(author=self.backend.name)
+            data = recipe_to_krecipes_xml(self.recipe, author=self.backend.name)
             try:
                 with codecs.open(dest, 'w', 'utf-8') as f:
                     f.write(data)
