@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
@@ -205,6 +205,9 @@ class Recipient(BaseAccount):
     # Needed for multispaces case
     origin_account_id = StringField('Account id which recipient belong to')
 
+    def __repr__(self):
+        return "<%s id=%r label=%r>" % (type(self).__name__, self.id, self.label)
+
 
 class AccountType(Enum):
     UNKNOWN          = 0
@@ -248,6 +251,18 @@ class AccountType(Enum):
     "Revolving credit"
 
 
+class AccountOwnerType(object):
+    """
+    Specifies the usage of the account
+    """
+    PRIVATE = u'PRIV'
+    """private personal account"""
+    ORGANIZATION = u'ORGA'
+    """professional account"""
+    ASSOCIATION = u'ASSO'
+    """association account"""
+
+
 class Account(BaseAccount):
     """
     Bank account.
@@ -274,6 +289,7 @@ class Account(BaseAccount):
     TYPE_REVOLVING_CREDIT = AccountType.REVOLVING_CREDIT
 
     type =      EnumField('Type of account', AccountType, default=TYPE_UNKNOWN)
+    owner_type = StringField('Usage of account')  # cf AccountOwnerType class
     balance =   DecimalField('Balance on this bank account')
     coming =    DecimalField('Sum of coming movements')
     iban =      StringField('International Bank Account Number', mandatory=False)
@@ -286,7 +302,7 @@ class Account(BaseAccount):
     number =    StringField('Shown by the bank to identify your account ie XXXXX7489')
     # market and lifeinssurance accounts
     valuation_diff = DecimalField('+/- values total')
-    valuation_diff_percent = DecimalField('+/- values ratio')
+    valuation_diff_ratio = DecimalField('+/- values ratio')
 
     # parent account
     #  - A checking account parent of a card account
@@ -300,6 +316,15 @@ class Account(BaseAccount):
     def __repr__(self):
         return "<%s id=%r label=%r>" % (type(self).__name__, self.id, self.label)
 
+    # compatibility alias
+    @property
+    def valuation_diff_percent(self):
+        return self.valuation_diff_ratio
+
+    @valuation_diff_percent.setter
+    def valuation_diff_percent(self, value):
+        self.valuation_diff_ratio = value
+
 
 class Loan(Account):
     """
@@ -439,7 +464,7 @@ class Investment(BaseObject):
     valuation =          DecimalField('Total current valuation of the Investment')
     vdate     =          DateField('Value date of the valuation amount')
     diff =               DecimalField('Difference between the buy cost and the current valuation')
-    diff_percent =       DecimalField('Difference in ratio (1 meaning 100%) between the buy cost and the current valuation')
+    diff_ratio =         DecimalField('Difference in ratio (1 meaning 100%) between the buy cost and the current valuation')
     portfolio_share =    DecimalField('Ratio (1 meaning 100%) of the current amount relative to the total')
 
     # International
@@ -452,6 +477,15 @@ class Investment(BaseObject):
     def __repr__(self):
         return '<Investment label=%r code=%r valuation=%r>' % (self.label, self.code, self.valuation)
 
+    # compatibility alias
+    @property
+    def diff_percent(self):
+        return self.diff_ratio
+
+    @diff_percent.setter
+    def diff_percent(self, value):
+        self.diff_ratio = value
+
 
 class PocketCondition(Enum):
     UNKNOWN                    = 0
