@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from prettytable import PrettyTable
@@ -88,7 +88,7 @@ class TableFormatter(IFormatter):
         for line in queue:
             for _ in range(maxrow - len(line)):
                 line += ('',)
-            table.add_row(line)
+            table.add_row([self.format_cell(cell) for cell in line])
 
         if self.HTML:
             s += table.get_html_string()
@@ -99,6 +99,12 @@ class TableFormatter(IFormatter):
 
         return s
 
+    def format_cell(self, cell):
+        if isinstance(cell, list):
+            return ', '.join(['%s' % item for item in cell])
+
+        return cell
+
     def format_dict(self, item):
         if self.keys is None:
             self.keys = list(item.keys())
